==> privacyidea_3.2.orig.tar.gz: privacyidea.orig/AUTHORS.md <==
# Authors in version 3.2

Cornelius Kölbel <cornelius.koelbel@netknights.it>
Friedrich Weber <friedrich.weber@netknights.it>
Paul Lettich <paul.lettich@netknights.it>
Jean-Pierre <jean-pierre.hoehmann@netknights.it>
debianis <db91@gmx.de>
Josef Wuebbels <josef.wuebbels@t-systems.com>
markroxor <mrmohitrathoremr@gmail.com>

# Overall authors

Cornelius Kölbel <cornelius.koelbel@netknights.it>
Friedrich Weber <friedrich.weber@netknights.it>
Paul Lettich <paul.lettich@netknights.it>
Jean-Pierre <jean-pierre.hoehmann@netknights.it>
Friedrich Weber <fred@reichbier.de>
Martin Wheldon <martin.wheldon@greenhills-it.co.uk>
Pavol Ipoth <pavol.ipoth@telekom.com>
jh23453 <jochen@jochen.org>
Jochen Hein <jochen@jochen.org>
jalr <mail@jalr.de>
yurlov-alexander <34740879+yurlov-alexander@users.noreply.github.com>
Andreas Böhler <dev@aboehler.at>
Dio <diogenes.santos-de-jesus@telekom.sk>
Micha Preußer <mail@mpreusser.de>
Quoc Doan <quoc@axiadids.com>
Bernd Nicklas <nicklas@hrz.uni-marburg.de>
Cody <cody@quantifiedcode.com>
Mathias Brossard <mathias@axiadids.com>
Nomen Nescio <info@nomennesc.io>
Omar Kohl <omarkohl@gmail.com>
Quynh Nguyen <quynh@axiadids.com>
Samuel Reed <samuel.trace.reed@gmail.com>
Sebastian Plattner <sebastian.plattner@ruag.com>
blinkiz <github@post.niklashagman.se>
quoc-axiadids <quoc@axiadids.com>
Lavesh Gupta <lavesh@Laveshs-MacBook-Pro.local>
M. Maraun <maraun@web.de>
Pascal   F u k s <pascal@foxit.pro>
Ryan Williams <rdw@appnexus.com>
Salvo Rapisarda <sdrapisarda@gmail.com>
AreRR <r.r.arends@hr.nl>
Daniel Hoffend <dh@dotlan.net>
Diogenes S. Jesus <splashx@users.noreply.github.com>
Fabian Cernota <cernota@chamaeleon.de>
Ivan Stojmirov <stojmir@gmail.com>
Jean-Guilhem Rouel <jean-gui@w3.org>
Josef Wuebbels <josef.wuebbels@t-systems.com>
Kleber Rocha <klinux@gmail.com>
Marc Welp <m.welp@phytec.de>
Rene Arends <renini@gmail.com>
René van Dorst <opensource@vdorst.com>
Richard Franks <git@rf152.co.uk>
Taylor Chase <Taylor.Chase@tempustechnologies.com>
Viktor Blesak <viktor.blesak@pan-net.eu>
Voyrx <48721490+Voyrx@users.noreply.github.com>
blsho <38477631+blsho@users.noreply.github.com>
frennkie <mail@rhab.de>
m7four <manfred.schmid@it-schmid.com>
mjbecker <39964311+mjbecker@users.noreply.github.com>
quynh-axiadids <quynh@axiadids.com>
renini <r.r.arends@hr.nl>
root <root@Svr040.livingston.nhsscotland.com>
Tamaro <tamaro.skaljic@netknights.it>
Bas van der Vlies <bas.vandervlies@surfsara.nl>
droobah <bananaboat@gmail.com>
debianis <db91@gmx.de>
Josef Wuebbels <josef.wuebbels@t-systems.com>
markroxor <mrmohitrathoremr@gmail.com>

Created using
git shortlog -sne ed39864429ca01452acb20bd1d0f340cf136bce6.. | cut -f 2,3

==> privacyidea_3.3.2.orig.tar.gz: privacyidea.orig/AUTHORS.md <==
# Authors in version 3.3

Cornelius Kölbel <cornelius.koelbel@netknights.it>
Paul Lettich <paul.lettich@netknights.it>
Jean-Pierre <jean-pierre.hoehmann@netknights.it>
Henning Hollermann <laclaro@mail.com>
Bruno <brunocascio@gmail.com>
Lavesh Gupta <lavesh@axiadids.com>
Niall Donegan <github@nialldonegan.me>
PhiBo <phibo@dinotools.org>


# Overall authors

Cornelius Kölbel <cornelius.koelbel@netknights.it>
Friedrich Weber <friedrich.weber@netknights.it>
Paul Lettich <paul.lettich@netknights.it>
Jean-Pierre <jean-pierre.hoehmann@netknights.it>
Martin Wheldon <martin.wheldon@greenhills-it.co.uk>
Pavol Ipoth <pavol.ipoth@telekom.com>
jh23453 <jochen@jochen.org>
Henning Hollermann <hollermann@physik.rwth-aachen.de>
Jochen Hein <jochen@jochen.org>
jalr <mail@jalr.de>
yurlov-alexander <34740879+yurlov-alexander@users.noreply.github.com>
Micha Preußer <mail@mpreusser.de>
Andreas Böhler <dev@aboehler.at>
Dio <diogenes.santos-de-jesus@telekom.sk>
Tamaro <49238587+tamaro-skaljic@users.noreply.github.com>
Micha Preußer <micha.preusser@netknights.it>
Quoc Doan <quoc@axiadids.com>
debianis <db91@gmx.de>
Bas van der Vlies <bas.vandervlies@surfsara.nl>
Bernd Nicklas <nicklas@hrz.uni-marburg.de>
Bruno <brunocascio@gmail.com>
Cody <cody@quantifiedcode.com>
Mathias Brossard <mathias@axiadids.com>
Nomen Nescio <info@nomennesc.io>
Omar Kohl <omarkohl@gmail.com>
Quynh Nguyen <quynh@axiadids.com>
Samuel Reed <samuel.trace.reed@gmail.com>
Sebastian Plattner <sebastian.plattner@ruag.com>
blinkiz <github@post.niklashagman.se>
quoc-axiadids <quoc@axiadids.com>
Jean-Pierre Höhmann <jp@hhmn.de>
Josef Wuebbels <josef.wuebbels@t-systems.com>
Lavesh Gupta <lavesh@Laveshs-MacBook-Pro.local>
M. Maraun <maraun@web.de>
Pascal   F u k s <pascal@foxit.pro>
Ryan Williams <rdw@appnexus.com>
Salvo Rapisarda <sdrapisarda@gmail.com>
droobah <bananaboat@gmail.com>
AreRR <r.r.arends@hr.nl>
Daniel Hoffend <dh@dotlan.net>
Diogenes S. Jesus <splashx@users.noreply.github.com>
Fabian Cernota <cernota@chamaeleon.de>
Henning Hollermann <laclaro@mail.com>
Ivan Stojmirov <stojmir@gmail.com>
Jean-Guilhem Rouel <jean-gui@w3.org>
Kleber Rocha <klinux@gmail.com>
Lavesh Gupta <lavesh@axiadids.com>
Marc Welp <m.welp@phytec.de>
Niall Donegan <github@nialldonegan.me>
Nils Behlen <nils.behlen@netknights.it>
PhiBo <phibo@dinotools.org>
Rene Arends <renini@gmail.com>
René van Dorst <opensource@vdorst.com>
Richard Franks <git@rf152.co.uk>
Taylor Chase <Taylor.Chase@tempustechnologies.com>
Viktor Blesak <viktor.blesak@pan-net.eu>
Voyrx <48721490+Voyrx@users.noreply.github.com>
blsho <38477631+blsho@users.noreply.github.com>
frennkie <mail@rhab.de>
m7four <manfred.schmid@it-schmid.com>
markroxor <mrmohitrathoremr@gmail.com>
mjbecker <39964311+mjbecker@users.noreply.github.com>
quynh-axiadids <quynh@axiadids.com>
renini <r.r.arends@hr.nl>
root <root@Svr040.livingston.nhsscotland.com>


Created using
git shortlog -sne ed39864429ca01452acb20bd1d0f340cf136bce6.. | cut -f 2,3
